<?php
/*
Plugin Name: TweetMeme Button
Plugin URI: http://tweetmeme.com/static.php?page=button 
Description: Adds the TweetMeme button into your posts and RSS feed.
Version: 1.4.2
Author: TweetMeme
Author URI: http://tweetmeme.com
*/

function tm_options() {
    add_options_page('TweetMeme Settings', 'TweetMeme', 8, basename(__FILE__), 'tm_options_page');
}

/* Code added by Eric Canon - http://linkup.com */
function tm_generate_button() {
    global $post;
    $url = '';
    if (get_post_status($post->ID) == 'publish') {   
        $url = get_permalink();
    } 
    
    $button = '<div id="tweetmeme_button" style="' . get_option('tm_style') . '">'.
                  '<script type="text/javascript">
                    tweetmeme_url = \'' . $url . '\';';
                        
    if (get_option('tm_source')) {
        $button .= 'tweetmeme_source = \'' . urlencode(get_option('tm_source')) . '\';';
    } 
                    
    if (get_option('tm_version') == 'compact') {
        $button .= 'tweetmeme_style = \'compact\';';
    }
    
    $button .= '
    </script><script type="text/javascript" src="http://tweetmeme.com/i/scripts/button.js"></script></div>';

    return $button;
}

function tm_update($content) {
    
    // add the manual option, code added by kovshenin 
    if (get_option('tm_where') == 'manual') {
        return $content;
    }
    
    if (get_option('tm_display_page') == null && is_page()) {
        return $content;
    }
    
    if (get_option('tm_display_feed') == null && is_feed()) {
        return $content;
    }
    
    // if we have switched the button off
    if (get_post_meta($post->ID, 'tweetmeme') == '') {
        $button = tm_generate_button();    
        // Before and After code added by http://www.jimyaghi.com
        if (get_option('tm_where') == 'beforeandafter') {
            return $button . $content . $button;
        } else if (get_option('tm_where') == 'before') {
            return $button . $content;
        } else {
            return $content . $button;
        }
    } else {
        return $content;
    }
}

// Manual output
function tweetmeme() {
    if (get_option('tm_where') == 'manual') {
        return tm_generate_button();
    } else {
        return false;
    }
}

// Remove the filter excerpts
// Code added by Soccer Dad
function tm_remove_filter($content) {
    remove_action('the_content', 'tm_update');
    return $content;
}

function tm_ping($post_id) {
    // do we have curl
    if ((get_option('tm_ping') != 'off') && function_exists('curl_init')) {
        $url = get_permalink($post_id);
        // create a new cURL resource
        $ch = curl_init();

        // set URL and other appropriate options
        curl_setopt($ch, CURLOPT_URL, 'http://api.tweetmeme.com/ping.php?url=' . urlencode($url));
        curl_setopt($ch, CURLOPT_CONNECTTIMEOUT, 2);  
        curl_setopt($ch, CURLOPT_TIMEOUT, 3);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);

        // grab URL and pass it to the browser
        curl_exec($ch);

        // close cURL resource, and free up system resources
        curl_close($ch);    
    }
}

function tm_options_page() {
?>
    <div class="wrap">
    <div class="icon32" id="icon-options-general"><br/></div><h2>Settings for Tweetmeme Integration</h2>
    <p>This plugin will install the tweetmeme widget for each of your blog posts in both the content of your posts and the RSS feed. 
    It can be easily styles in your blog posts and is referenced by the id <code>tweetmeme_button</code>. 
    </p>
    <form method="post" action="options.php">
    <?php
        // New way of setting the fields, for WP 2.7 and newer
        if(function_exists('settings_fields')){
            settings_fields('tm-options');
        } else {
            wp_nonce_field('update-options');
            ?>
            <input type="hidden" name="action" value="update" />
            <input type="hidden" name="page_options" value="tm_ping,tm_where,tm_style,tm_version,tm_display_page,tm_display_feed,tm_source" />
            <?php
        }
    ?>  
        <table class="form-table">
            <tr>
                <th scope="row">
                    Position
                </th>
                <td>
                    <p>
                        <input type="radio" value="before" <?php if (get_option('tm_where') == 'before') echo 'checked="checked"'; ?> id="tm_where_before" name="tm_where" group="tm_where"/> 
                        <label for="tm_where_before">Before the content of your post</label>     
                    </p>
                    <p>
                        <input type="radio" value="after" <?php if (get_option('tm_where') == 'after') echo 'checked="checked"'; ?> name="tm_where" id="tm_where_after" group="tm_where" />
                        <label for="tm_where_after">After the content of your post</label>    
                    </p>
                    <p>
                        <input type="radio" value="beforeandafter" <?php if (get_option('tm_where') == 'beforeandafter') echo 'checked="checked"'; ?> name="tm_where" id="tm_where_both" group="tm_where"/> 
                        <label for="tm_where_both">Before AND After the content of your post</label>     
                    </p>
                    <p>
                        <input type="radio" value="manual" <?php if (get_option('tm_where') == 'manual') echo 'checked="checked"'; ?> name="tm_where" id="tm_where_manual" group="tm_where"/> 
                        <label for="tm_where_manual">Manually call the retweet button</label> <br/>    
                        <span class="setting-description">You can manually call the <code>tweetmeme()</code> function. E.g. <code>if (function_exists('tweetmeme')) echo tweetmeme();</code>.<br/> N.B. this will disable the display of the button in your feed and pages.</span>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    Type
                </th>
                <td>
                    <p>
                        <input type="radio" value="large" <?php if (get_option('tm_version') == 'large') echo 'checked="checked"'; ?> name="tm_version" id="tm_version_large" group="tm_version"/> 
                        <label for="tm_version_large">The normal size widget</label>     
                    </p>
                    <p>
                        <input type="radio" value="compact" <?php if (get_option('tm_version') == 'compact') echo 'checked="checked"'; ?> name="tm_version" id="tm_version_compact" group="tm_version" />
                        <label for="tm_version_compact">The compact widget</label>    
                    </p>
                </td>
            </tr> 
            <tr>
                <th scope="row">
                    Display
                </th>
                <td>
                    <p>
                        <input type="checkbox" value="1" <?php if (get_option('tm_display_page') == '1') echo 'checked="checked"'; ?> name="tm_display_page" id="tm_display_page" group="tm_display"/> 
                        <label for="tm_display_page">Display the button on pages</label>     
                    </p>
                    <p>
                        <input type="checkbox" value="1" <?php if (get_option('tm_display_feed') == '1') echo 'checked="checked"'; ?> name="tm_display_feed" id="tm_display_feed" group="tm_display" />
                        <label for="tm_display_feed">Display the button on your feed</label>    
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    Source
                </th>
                <td>
                    <p>
                        RT @<input type="text" value="<?php echo get_option('tm_source'); ?>" name="tm_source" id="tm_source" /> 
                        <label for="tm_source">Change the RT source of the button from RT @tweetmeme to RT @yourname</label>    <br/>
                        <span class="setting-description">Please use the format of 'yourname', not 'RT @yourname'. For more information please see the <a href="http://help.tweetmeme.com">help</a>.</span> 
                    </p>
                </td>
            </tr>  
            <tr>
                <th scope="row"><label for="tm_style">Styling</label></th>
                <td>
                    <input type="text" value="<?php echo htmlspecialchars(get_option('tm_style')); ?>" name="tm_style" id="tm_style" />
                    <span class="setting-description">Add style to the div that surrounds the button E.g. <code>float: left; margin-right: 10px;</code></span>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label for="tm_ping">Ping Tweetmeme</label>
                </th>
                <td>
                    <p>
                        <input type="radio" value="on" <?php if (get_option('tm_ping') == 'on') echo 'checked="checked"'; ?> name="tm_ping" id="tm_ping_on" group="tm_ping"/> 
                        <label for="tm_ping_on">Yes</label>     
                    </p>
                    <p>
                        <input type="radio" value="off" <?php if (get_option('tm_ping') == 'off') echo 'checked="checked"'; ?> name="tm_ping" id="tm_ping_off" group="tm_ping" />
                        <label for="tm_ping_off">No</label>    
                    </p>
                    <span class="setting-description">Alert TweetMeme whenever a new post is published, so it can update the details. Like the post title.</p>
                </td>
            </tr>  
        </table>
        <p class="submit">
            <input type="submit" name="Submit" value="<?php _e('Save Changes') ?>" />
        </p>
    </form>
    </div>
<?php
}

// On access of the admin page, register these variables (required for WP 2.7 & newer)
function tm_init(){
    if(function_exists('register_setting')){
        register_setting('tm-options', 'tm_display_feed');
        register_setting('tm-options', 'tm_display_page');
        register_setting('tm-options', 'tm_source', 'tm_sanitize_username');
        register_setting('tm-options', 'tm_style');
        register_setting('tm-options', 'tm_version');
        register_setting('tm-options', 'tm_where');
        register_setting('tm-options', 'tm_ping');
    }
}

function tm_sanitize_username($username){
    return preg_replace('/[^A-Za-z0-9_]/','',$username);
}


// Only all the admin options if the user is an admin
if(is_admin()){
    add_action('admin_menu', 'tm_options');
    add_action('admin_init', 'tm_init');
}

//Set the default options when the plugin is activated
function tm_activate(){
    add_option('tm_where');
    add_option('tm_source');
    add_option('tm_style', 'float: left; margin-right: 10px;');  
    add_option('tm_version', 'large'); 
    add_option('tm_display_page', '1');
    add_option('tm_display_feed', '1');
    add_option('tm_ping', 'on');
}

add_filter('the_content', 'tm_update');
add_filter('get_the_excerpt', 'tm_remove_filter', 9); 

add_action('publish_post', 'tm_ping', 9);

register_activation_hook( __FILE__, 'tm_activate' );